﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;

namespace System.Windows.Controls
{
  /// <summary>
  /// Base class for Silverlight DataTemplateSelector.
  /// </summary>
  public class DataTemplateSelector : ContentControl
  {
    /// <summary>
    /// Called when the value of the <see cref="System.Windows.Controls.ContentControl.Content"/> property changes.
    /// </summary>
    protected override void OnContentChanged(object oldContent, object newContent)
    {
      base.OnContentChanged(oldContent, newContent);

      var template = SelectTemplate(newContent, null);
      if (template != null)
        ContentTemplate = template;
    }

    /// <summary>
    /// When overridden in a derived class, returns a DataTemplate based on custom logic.
    /// </summary>
    /// <param name="item">The data object for which to select the template. </param>
    /// <param name="notUsedInSilverlight">The not used in silverlight. Exists for WPF compatibility only.</param>
    /// <returns>Returns a DataTemplate or a null reference. The default value is a null reference.</returns>
    public virtual DataTemplate SelectTemplate(object item, DependencyObject notUsedInSilverlight)
    {
      return null;
    }
  }
}
